@@ -3,5 +3,5 @@
 set -x
 aclocal
 autoconf
-automake
+automake --add-missing --copy --foreign
 
