@@ -29,7 +29,6 @@
 #include <sys/stat.h>
 #include <sys/ioctl.h>
 #include <fcntl.h>
-#include <asm-arm/arch-omap/dsp.h>
 #include "dspctl.h"
 
 enum regspace { SPACE_MEM, SPACE_IO };
@@ -45,6 +44,7 @@ static void driver_version_check(void);
 static int do_start(char **argv);
 static int do_stop(char **argv);
 static int do_version(char **argv);
+static int do_dspversion(char **argv);
 static int do_load(char **argv);
 static int do_run(char **argv);
 static int do_reset(char **argv);
@@ -79,6 +79,7 @@ static int do_regwrite_io(char **argv);
 static int __regwrite(enum regspace space, unsigned short adr, unsigned short val);
 static int do_runlevel(char **argv);
 static int do_mbsend(char **argv);
+static int do_memstatus(char **argv);
 
 static void usage(char *cmd)
 {
@@ -89,6 +90,7 @@ static void usage(char *cmd)
 		"    stop\n"
 		"\n"
 		"    version <cofffile>\n"
+		"    dspversion\n"
 		"    load <cofffile>\n"
 		"    run (=unreset)\n"
 		"    reset\n"
@@ -118,12 +120,14 @@ static void usage(char *cmd)
 		"    regread [-io] <adr>\n"
 		"    regwrite [-io] <adr> <val>\n"
 		"    runlevel <user|super>\n"
+		"    memstatus\n"
 		"    mbsend <cmd> <data>\n");
 }
 
 static struct ctlcmd ctlcmd[] = {
 	{ "start",        3, do_start },
 	{ "stop",         2, do_stop },
+	{ "dspversion",   2, do_dspversion },
 	{ "version",      3, do_version },
 	{ "load",         3, do_load },
 	{ "run",          2, do_run },
@@ -157,6 +161,7 @@ static struct ctlcmd ctlcmd[] = {
 	{ "regwrite",     4, do_regwrite },
 	{ "regwrite",     5, do_regwrite_io },
 	{ "runlevel",     3, do_runlevel },
+	{ "memstatus",    2, do_memstatus },
 	{ "mbsend",       4, do_mbsend },
 	{ NULL, 0, NULL },
 };
@@ -403,6 +408,23 @@ static int do_version(char **argv)
 	return 0;
 }
 
+static int do_dspversion(char **argv)
+{
+	struct omap_dsp_mailbox_cmd mbcmd;
+	int fd;
+
+	mbcmd.cmd  = 0x7408;
+	mbcmd.data = 0;
+
+	if ((fd = open(CTLDEVNM, O_RDWR)) < 0) {
+		perror("open control device");
+		return 1;
+	}
+	ioctl(fd, OMAP_DSP_IOCTL_MBSEND, &mbcmd);
+	close(fd);
+	return 0;
+}
+
 static int do_load(char **argv)
 {
 	char *coffname = argv[2];
@@ -1086,6 +1108,23 @@ static int do_runlevel(char **argv)
 	return 0;
 }
 
+static int do_memstatus(char **argv)
+{
+	struct omap_dsp_mailbox_cmd mbcmd;
+	int fd;
+
+	mbcmd.cmd  = 0x7409;
+	mbcmd.data = 0;
+
+	if ((fd = open(CTLDEVNM, O_RDWR)) < 0) {
+		perror("open control device");
+		return 1;
+	}
+	ioctl(fd, OMAP_DSP_IOCTL_MBSEND, &mbcmd);
+	close(fd);
+	return 0;
+}
+
 static int do_mbsend(char **argv)
 {
 	struct omap_dsp_mailbox_cmd mbcmd;
